@@ -17,6 +17,13 @@ class MTRouteType(str, Enum):
     FailoverMTRoute = 'FailoverMTRoute'
 
 
+class MORouteType(str, Enum):
+    DefaultRoute = 'DefaultRoute'
+    StaticMORoute = 'StaticMORoute'
+    RandomRoundrobinMORoute = 'FailoverMORoute'
+    FailoverMORoute = 'FailoverMORoute'
+
+
 class FilterType(str, Enum):
     TransparentFilter = 'TransparentFilter'
     ConnectorFilter = 'ConnectorFilter'
@@ -59,7 +66,8 @@ class JasminManager(object):
 
             yield self.child
         except ExceptionPexpect as exc:
-            raise JasminException('Unable to connect to jasmin service') from exc
+            raise JasminException(
+                'Unable to connect to jasmin service') from exc
         finally:
             if self.child:
                 self.child.sendline('persist')
@@ -106,7 +114,8 @@ class JasminManager(object):
         for line in raw_data:
             if line.startswith('jcli'):
                 continue
-            inspect_lines.append([data for data in line.split(' ') if data != ''])
+            inspect_lines.append(
+                [data for data in line.split(' ') if data != ''])
 
         return inspect_lines
 
@@ -295,84 +304,59 @@ class JasminUserManager(JasminManager):
                 child.sendline(f'gid {gid}')
             if password:
                 child.sendline(f'password {password}')
-            if http_send:
-                child.sendline(
-                    f'mt_messaging_cred authorization http_send {http_send}')
-            if http_balance:
-                child.sendline(
-                    f'mt_messaging_cred authorization http_balance {http_balance}')
-            if http_rate:
-                child.sendline(
-                    f'mt_messaging_cred authorization http_rate {http_rate}')
-            if http_bulk:
-                child.sendline(
-                    f'mt_messaging_cred authorization http_bulk {http_bulk}')
+            child.sendline(
+                f'mt_messaging_cred authorization http_send {http_send}')
+            child.sendline(
+                f'mt_messaging_cred authorization http_balance {http_balance}')
+            child.sendline(
+                f'mt_messaging_cred authorization http_rate {http_rate}')
+            child.sendline(
+                f'mt_messaging_cred authorization http_bulk {http_bulk}')
             child.sendline(
                 f'mt_messaging_cred authorization smpps_send {smpps_send}')
-            if http_long_content:
-                child.sendline(
-                    f'mt_messaging_cred authorization http_long_content {http_long_content}')
-            if dlr_level:
-                child.sendline(
-                    f'mt_messaging_cred authorization dlr_level {dlr_level}')
-            if http_dlr_method:
-                child.sendline(
-                    f'mt_messaging_cred authorization http_dlr_method {http_dlr_method}')
-            if src_addr:
-                child.sendline(
-                    f'mt_messaging_cred authorization src_addr {src_addr}')
-            if priority:
-                child.sendline(
-                    f'mt_messaging_cred authorization priority {priority}')
-            if validity_period:
-                child.sendline(
-                    f'mt_messaging_cred authorization validity_period {validity_period}')
-            if schedule_delivery_time:
-                child.sendline(
-                    f'mt_messaging_cred authorization schedule_delivery_time {schedule_delivery_time}')
-            if hex_content:
-                child.sendline(
-                    f'mt_messaging_cred authorization hex_content {hex_content}')
+            child.sendline(
+                f'mt_messaging_cred authorization http_long_content {http_long_content}')
+            child.sendline(
+                f'mt_messaging_cred authorization dlr_level {dlr_level}')
+            child.sendline(
+                f'mt_messaging_cred authorization http_dlr_method {http_dlr_method}')
+            child.sendline(
+                f'mt_messaging_cred authorization src_addr {src_addr}')
+            child.sendline(
+                f'mt_messaging_cred authorization priority {priority}')
+            child.sendline(
+                f'mt_messaging_cred authorization validity_period {validity_period}')
+            child.sendline(
+                f'mt_messaging_cred authorization schedule_delivery_time {schedule_delivery_time}')
+            child.sendline(
+                f'mt_messaging_cred authorization hex_content {hex_content}')
 
             child.expect(['>'])
 
-            if dst_addr:
-                child.sendline(
-                    f'mt_messaging_cred valuefilter dst_addr {dst_addr}')
-            if valuefilter_src_addr:
-                child.sendline(
-                    f'mt_messaging_cred valuefilter src_addr {valuefilter_src_addr}')
-            if valuefilter_priority:
-                child.sendline(
-                    f'mt_messaging_cred valuefilter priority {valuefilter_priority}')
-            if valuefilter_validity_period:
-                child.sendline(
-                    f'mt_messaging_cred valuefilter validity_period {valuefilter_validity_period}')
-            if content:
-                child.sendline(
-                    f'mt_messaging_cred valuefilter content {content}')
-            if defaultvalue_src_addr:
-                child.sendline(
-                    f'mt_messaging_cred defaultvalue src_addr {defaultvalue_src_addr}')
-            if balance:
-                child.sendline(f'mt_messaging_cred quota balance {balance}')
-            if early_percent:
-                child.sendline(
-                    f'mt_messaging_cred quota early_percent {early_percent}')
-            if sms_count:
-                child.sendline(
-                    f'mt_messaging_cred quota sms_count {sms_count}')
-            if http_throughput:
-                child.sendline(
-                    f'mt_messaging_cred quota http_throughput {http_throughput}')
-            if smpps_throughput:
-                child.sendline(
-                    f'mt_messaging_cred quota smpps_throughput {smpps_throughput}')
-            if bind:
-                child.sendline(f'smpps_cred authorization bind {bind}')
-            if max_bindings:
-                child.sendline(
-                    f'smpps_cred quota max_bindings {max_bindings}')
+            child.sendline(
+                f'mt_messaging_cred valuefilter dst_addr {dst_addr}')
+            child.sendline(
+                f'mt_messaging_cred valuefilter src_addr {valuefilter_src_addr}')
+            child.sendline(
+                f'mt_messaging_cred valuefilter priority {valuefilter_priority}')
+            child.sendline(
+                f'mt_messaging_cred valuefilter validity_period {valuefilter_validity_period}')
+            child.sendline(
+                f'mt_messaging_cred valuefilter content {content}')
+            child.sendline(
+                f'mt_messaging_cred defaultvalue src_addr {defaultvalue_src_addr}')
+            child.sendline(f'mt_messaging_cred quota balance {balance}')
+            child.sendline(
+                f'mt_messaging_cred quota early_percent {early_percent}')
+            child.sendline(
+                f'mt_messaging_cred quota sms_count {sms_count}')
+            child.sendline(
+                f'mt_messaging_cred quota http_throughput {http_throughput}')
+            child.sendline(
+                f'mt_messaging_cred quota smpps_throughput {smpps_throughput}')
+            child.sendline(f'smpps_cred authorization bind {bind}')
+            child.sendline(
+                f'smpps_cred quota max_bindings {max_bindings}')
 
             child.sendline('ok')
 
@@ -811,3 +795,83 @@ class JasminMTRouterManager(JasminManager):
 
     def inspect(self, id: str):
         pass
+
+
+class JasminMORouterManager(JasminManager):
+    __base_cmd__ = 'morouter'
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def add(self, order: int, type: MORouteType = MORouteType.DefaultRoute, **kwargs) -> bool:
+        """Create a new MO Route
+
+        Args:
+            order (int): Route Order
+            type (MTRouteType, optional): Route type. Defaults to MTRouteType.DefaultRoute.
+            **kwargs (dict): Additional parameters according to route type
+
+        Returns:
+            bool: True is operation is successful, otherwise False
+        """
+        with self.connect() as child:
+            child.sendline('{} --add'.format(self.__base_cmd__))
+            child.expect('')
+            child.sendline(f'type {type}')
+            child.expect('')
+            child.sendline('order {}'.format(order))
+            child.expect('')
+            for key, value in kwargs.items():
+                child.sendline(f'{key} {value}')
+                child.expect('')
+            child.sendline('ok')
+            child.expect('')
+
+        return self._get_operation_status()
+
+    def remove(self, order: int) -> bool:
+        """Remove MO Route using its order
+
+        Args:
+            order (int): MO Route order
+
+        Returns:
+            bool: True is operation is successful, otherwise False
+        """
+        with self.connect() as child:
+            child.sendline('{} -r {}'.format(self.__base_cmd__, order))
+            child.expect('')
+
+        return self._get_operation_status()
+
+    def update(self, *args, **kwargs):
+        pass
+
+    def list(self) -> List[JasminMTRoute]:
+        """List MO Routes
+
+        Returns:
+            List[JasminMORoute]: MO Routes list
+        """
+        global lines
+        with self.connect() as child:
+            child.sendline(f'{self.__base_cmd__} -l')
+            lines = self._parse_list('Total MO Routes:')
+
+        return [JasminMORoute.from_line(line) for line in lines]
+
+    def flush(self) -> bool:
+        """Flush MO Routing table. 
+        Be careful, this action is UNRECOVERABLE!
+
+        Returns:
+            bool: True is operation is successful, otherwise False
+        """
+        with self.connect() as child:
+            child.sendline(f'{self.__base_cmd__} -f')
+            child.expect('')
+
+        return self._get_operation_status()
+
+    def inspect(self, id: str):
+        pass
